==> hoteldruid-mod-pt_2.1.2-2.zip: pt/giorni_mesi.php <==
<?php

switch ($messaggio) {

case " Do":  					$messaggio = " Do"; break;
case " Lu":  					$messaggio = " 2a"; break;
case " Ma":  					$messaggio = " 3a"; break;
case " Me":  					$messaggio = " 4a"; break;
case " Gi":  					$messaggio = " 5a"; break;
case " Ve":  					$messaggio = " 6a"; break;
case " Sa":  					$messaggio = " Sá"; break;
case "Gen":  					$messaggio = "Jan"; break;
case "Feb":  					$messaggio = "Fev"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Abr"; break;
case "Mag":  					$messaggio = "Mai"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Ago"; break;
case "Set":  					$messaggio = "Set"; break;
case "Ott":  					$messaggio = "Out"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dez"; break;
case "Gennaio":  				$messaggio = "Janeiro"; break;
case "Febbraio":  				$messaggio = "Fevereiro"; break;
case "Marzo":  					$messaggio = "Março"; break;
case "Aprile":  				$messaggio = "Abril"; break;
case "Maggio":  				$messaggio = "Maio"; break;
case "Giugno":  				$messaggio = "Junho"; break;
case "Luglio":  				$messaggio = "Julho"; break;
case "Agosto":  				$messaggio = "Agosto"; break;
case "Settembre":  				$messaggio = "Setembro"; break;
case "Ottobre":  				$messaggio = "Outubro"; break;
case "Novembre":  				$messaggio = "Novembro"; break;
case "Dicembre":  				$messaggio = "Dezembro"; break;
case "Domenica":  				$messaggio = "Domingo"; break;
case "Lunedì":  				$messaggio = "Segunda feira"; break;
case "Martedì":  				$messaggio = "Terça feira"; break;
case "Mercoledì":  				$messaggio = "Quarta feira"; break;
case "Giovedì":  				$messaggio = "Quinta feira"; break;
case "Venerdì":  				$messaggio = "Sexta feira"; break;
case "Sabato":  				$messaggio = "Sábado"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-pt_3.0.8-1.zip: pt/giorni_mesi.php <==
<?php

switch ($messaggio) {

# Space and 2 letters for days, 3 letters for months abbreviation

case " Do":  					$messaggio = " Do"; break;
case " Lu":  					$messaggio = " 2ª"; break;
case " Ma":  					$messaggio = " 3ª"; break;
case " Me":  					$messaggio = " 4ª"; break;
case " Gi":  					$messaggio = " 5ª"; break;
case " Ve":  					$messaggio = " 6ª"; break;
case " Sa":  					$messaggio = " Sá"; break;
case "Gen":  					$messaggio = "Jan"; break;
case "Feb":  					$messaggio = "Fev"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Abr"; break;
case "Mag":  					$messaggio = "Mai"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Ago"; break;
case "Set":  					$messaggio = "Set"; break;
case "Ott":  					$messaggio = "Out"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dez"; break;
case "Gennaio":  				$messaggio = "Janeiro"; break;
case "Febbraio":  				$messaggio = "Fevereiro"; break;
case "Marzo":  					$messaggio = "Março"; break;
case "Aprile":  				$messaggio = "Abril"; break;
case "Maggio":  				$messaggio = "Maio"; break;
case "Giugno":  				$messaggio = "Junho"; break;
case "Luglio":  				$messaggio = "Julho"; break;
case "Agosto":  				$messaggio = "Agosto"; break;
case "Settembre":  				$messaggio = "Setembro"; break;
case "Ottobre":  				$messaggio = "Outubro"; break;
case "Novembre":  				$messaggio = "Novembro"; break;
case "Dicembre":  				$messaggio = "Dezembro"; break;
case "Domenica":  				$messaggio = "Domingo"; break;
case "Lunedì":  				$messaggio = "Segunda-feira"; break;
case "Martedì":  				$messaggio = "Terça-feira"; break;
case "Mercoledì":  				$messaggio = "Quarta-feira"; break;
case "Giovedì":  				$messaggio = "Quinta-feira"; break;
case "Venerdì":  				$messaggio = "Sexta-feira"; break;
case "Sabato":  				$messaggio = "Sábado"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
